ExerciseSummary class

Constructors

ExerciseSummary({required String exerciseId, required int setsCompleted, required int repsTotal, required double volume})

Properties

exerciseId String
final
hashCode int
The hash code for this object.
no setterinherited
repsTotal int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setsCompleted int
final
volume double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited