Muscle class

Constructors

Muscle({required String id, required String name, String? group})

Properties

group String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

muscles List<Muscle>
final

Static Methods

findByName(String name) Muscle?
getByGroup(String group) List<Muscle>
getDefaultMuscles() List<Muscle>