PerformedExercise class
Constructors
-
PerformedExercise({required int exerciseIndex, required String exerciseName, required List<
PerformedSet> sets}) -
PerformedExercise.fromJson(Map<
String, dynamic> json) -
factory
Properties
- exerciseIndex → int
-
final
- exerciseName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
sets
→ List<
PerformedSet> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited