PerformedSet class

Constructors

PerformedSet({required int exerciseIndex, required int setIndex, required int actualReps, double? actualWeight, int? rir, Duration? pause, Duration? duration, required DateTime completedAt})
PerformedSet.fromJson(Map<String, dynamic> json)
factory

Properties

actualReps int
final
actualWeight double?
final
completedAt DateTime
final
duration Duration?
final
exerciseIndex int
final
hashCode int
The hash code for this object.
no setterinherited
pause Duration?
final
rir int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
setIndex int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited