PrefsRunnerStorage class
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearPlan(
{String key = "default"}) → Future< void> -
override
-
clearState(
{String key = "default"}) → Future< void> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readPlan(
{String key = "default"}) → Future< Map< String, dynamic> ?> -
override
-
readState(
{String key = "default"}) → Future< Map< String, dynamic> ?> -
override
-
savePlan(
{String key = "default", required Map< String, dynamic> json}) → Future<void> -
override
-
saveState(
{String key = "default", required Map< String, dynamic> json}) → Future<void> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited