QuickRunner class

Kompakter Card-Banner, der entweder den CurrentExercise-Pager einblendet (wenn keine aktive Übung existiert) oder – bei aktiver Übung – die Sätze der aktuellen Übung mit Start/Stop/Edit-Logik zeigt. Controller bitte mit übergeben

Inheritance

Constructors

QuickRunner({Key? key, required WorkoutRunnerController controller, List<WorkoutPlan>? plans, void onFinished(WorkoutResult?)?, Route<void> runnerRouteBuilder(BuildContext context, WorkoutPlan plan)?})
const

Properties

controller WorkoutRunnerController
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onFinished → void Function(WorkoutResult?)?
final
plans List<WorkoutPlan>?
final
runnerRouteBuilder Route<void> Function(BuildContext context, WorkoutPlan plan)?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<QuickRunner>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited