RunnerStorage class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearPlan(
{String key = "default"}) → Future< void> -
clearState(
{String key = "default"}) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readPlan(
{String key = "default"}) → Future< Map< String, dynamic> ?> -
readState(
{String key = "default"}) → Future< Map< String, dynamic> ?> -
savePlan(
{String key = "default", required Map< String, dynamic> json}) → Future<void> -
saveState(
{String key = "default", required Map< String, dynamic> json}) → Future<void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited