WorkoutExercise class

Constructors

WorkoutExercise({required String id, required String name, String? desc, ExerciseCategorie? category, List<Muscle>? muscles, required List<WorkoutSet> sets, String? notes, Map<String, dynamic>? meta})
WorkoutExercise.fromDefaultsByName(String name)
factory
WorkoutExercise.fromJson(Map<String, dynamic> json)
factory

Properties

category ExerciseCategorie?
final
desc String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
meta Map<String, dynamic>?
final
muscles List<Muscle>?
final
name String
final
notes String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sets List<WorkoutSet>
final

Methods

copyWith({String? id, String? name, String? desc, ExerciseCategorie? category, List<Muscle>? muscles, List<WorkoutSet>? sets, String? notes, Map<String, dynamic>? meta}) WorkoutExercise
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited