WorkoutRunnerController class

Inheritance

Constructors

WorkoutRunnerController()
factory

Properties

activeExerciseIndex int
no setter
activeSetExerciseIndex int?
no setter
activeSetIndex int?
no setter
currentExercise WorkoutExercise?
no setter
currentExerciseIndex int
no setter
currentSetElapsed Duration
no setter
defaultSetRest Duration
getter/setter pair
elapsed Duration
getter/setter pair
exercises List<WorkoutExercise>
no setter
hasActiveExercise bool
no setter
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isResting bool
no setter
isRunning bool
no setter
isSetRunning bool
no setter
onWorkoutFinished ↔ void Function(WorkoutResult)?
getter/setter pair
plan WorkoutPlan?
no setter
restRemaining Duration
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state WorkoutRunnerState?
no setter
tickEvery Duration
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
addSetToExercise(int exerciseIndex, {int? targetReps, double? targetWeight, Duration? rest}) Future<bool>
beginRest({int seconds = 90}) → void
canActivateSet(int exerciseIndex) bool
changeExerciseIndex(int newIndex) → void
clearActiveExercise() → void
completeSet({required int exerciseIndex, required int setIndex, required double weight, required int reps, required int rir, Duration? setDuration, Duration? pauseDuration}) Future<void>
configure({RunnerStorage? storage, bool autoResume = true}) Future<void>
hier Kann ein andere Speicher wie Datenbank ETC über die Klasse RunnerStorage erstellt werden zb. : class MysqlWorkoutStorage implements RunnerStorage
dispose() → void
Discards any resources used by the object.
inherited
finish() Future<WorkoutResult?>
finishActiveSet({required double weight, required int reps, required int rir, Duration? setDuration, int restSeconds = 90}) Future<bool>
getPerformedSet(int exerciseIndex, int setIndex) PerformedSet?
isExerciseActive(int index) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeSetFromExercise(int exerciseIndex, int setIndex) Future<bool>
setActiveExercise(int index) → void
skipRest() → void
start(WorkoutPlan plan, {bool resumeIfPossible = true}) Future<void>
startSet(int exerciseIndex, int setIndex) bool
toString() String
A string representation of this object.
inherited
updatePerformedSet({required int exerciseIndex, required int setIndex, required double weight, required int reps, required int rir}) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited